from setuptools import setup, find_packages


setup(
    name='sprache',
    version='0.1',
    description='NLP for India',
    license='MIT',
    author="Aditya Mandke",
    author_email='ekdnam@gmail.com',
    url='https://github.com/ekdnam/sprache',
    python_requires='>=3',
    keywords='example project',
    install_requires=[
          'scikit-learn',
      ]
)